@@ -195,11 +195,11 @@ def to_be_like(topic, expected):
     if not result:
         if isinstance(topic, string_types + (binary_type, )) and isinstance(expected, string_types + (binary_type, )):
             matcher, first, second = compare(_strip_string(topic), _strip_string(expected))
-            print
-            print "Expected strings to be equal, but they were different:"
-            print first
-            print second
-            print
+            print()
+            print("Expected strings to be equal, but they were different:")
+            print(first)
+            print(second)
+            print()
         raise AssertionError("Expected '%s' to be like '%s'." % (topic, expected))
 
 
